==> apollinaire-0.15-py2.py3-none-any.whl: apollinaire/peakbagging/__init__.py <==
from .likelihood import perform_mle

from .hessian import evaluate_precision

from .fit_tools import *

from .analyse_window import sidelob_param

from .peakbagging import (peakbagging, 
                          get_list_order)

from .bayesian import (wrap_explore_distribution, 
                      explore_distribution, 
                      show_chain)

from .chain_reader import (hdf5_to_a2z, read_chain,  
                           chain_to_a2z, hdf5_to_pkb)

from .background import (perform_mle_background, 
                        explore_distribution_background,
                        extract_param,
                        visualise_background,
                        background_model, build_background,
                        numax_scale, dnu_scale, create_labels,
                        background_guess, get_low_bounds, get_up_bounds)

from .global_pattern import (perform_mle_pattern, 
                             explore_distribution_pattern,
                             pattern_to_a2z, hide_modes,
                             remove_pattern)

from .rotation import (perform_mle_rotation, 
                       explore_distribution_rotation, peak_model, rotation_model)

from .stellar_framework import stellar_framework

from .a2z_no_pandas import wrapper_a2z_to_pkb_nopandas

from .quality_assurance import (bayes_factor, test_h0, compute_lnK, compute_thresholds)

from .mode_selection import select_mode_to_fit

from .save_chain import clean_empty_chains

from .test import test_a2z

from .banana_diagram import banana_diagram

==> apollinaire-0.16-py2.py3-none-any.whl: apollinaire/peakbagging/__init__.py <==
from .likelihood import perform_mle

from .hessian import evaluate_precision

from .fit_tools import *

from .analyse_window import sidelob_param

from .peakbagging import (peakbagging, 
                          get_list_order)

from .bayesian import (wrap_explore_distribution, 
                      explore_distribution)

from .chain_reader import (hdf5_to_a2z, read_chain,  
                           chain_to_a2z, hdf5_to_pkb,
                           cornerplot_flatchain)

from .background import (perform_mle_background, 
                        explore_distribution_background,
                        extract_param,
                        visualise_background,
                        background_model, build_background,
                        numax_scale, dnu_scale, create_labels,
                        background_guess, get_low_bounds, get_up_bounds,
                        create_background_guess_arrays)

from .global_pattern import (perform_mle_pattern, 
                             explore_distribution_pattern,
                             pattern_to_a2z, hide_modes,
                             remove_pattern,
                             create_pattern_guess_arrays,
                             compute_model_from_pattern)

from .rotation import (perform_mle_rotation, 
                       explore_distribution_rotation, peak_model, rotation_model)

from .stellar_framework import stellar_framework

from .a2z_no_pandas import wrapper_a2z_to_pkb_nopandas

from .quality_assurance import (bayes_factor, test_h0, compute_lnK, compute_thresholds)

from .mode_selection import select_mode_to_fit

from .save_chain import clean_empty_chains

from .test import test_a2z

from .banana_diagram import banana_diagram
